@@ -196,6 +196,12 @@ public class ClassWriter implements ClassVisitor {
    */
 
   private boolean computeMaxs;
+  
+  /**
+   * <tt>true</tt> to test that all attributes are known.
+   */
+  
+  boolean checkAttributes;
 
   /**
    * The methods of this class. These methods are stored in a linked list of
@@ -463,7 +469,7 @@ public class ClassWriter implements ClassVisitor {
    */
 
   public ClassWriter (final boolean computeMaxs) {
-    this(computeMaxs, 45, 3);
+    this(computeMaxs, false);
   }
 
   /**
@@ -476,11 +482,15 @@ public class ClassWriter implements ClassVisitor {
    *      CodeVisitor} returned by the {@link #visitMethod visitMethod} method
    *      will be ignored, and computed automatically from the signature and
    *      the bytecode of each method.
-   * @param major the major version of the class to be generated.
-   * @param minor the minor version of the class to be generated.
+   * @param skipUnknownAttributes <tt>true</tt> to silently ignore unknown 
+   *      attributes, or <tt>false</tt> to throw an exception if an unknown
+   *      attribute is found.
    */
 
-  public ClassWriter (final boolean computeMaxs, final int major, final int minor) {
+  public ClassWriter (
+    final boolean computeMaxs, 
+    final boolean skipUnknownAttributes) 
+  {
     index = 1;
     pool = new ByteVector();
     items = new Item[64];
@@ -489,7 +499,7 @@ public class ClassWriter implements ClassVisitor {
     key2 = new Item();
     key3 = new Item();
     this.computeMaxs = computeMaxs;
-    this.version = minor << 16 | major;
+    this.checkAttributes = !skipUnknownAttributes;
   }
 
   // --------------------------------------------------------------------------
@@ -497,12 +507,14 @@ public class ClassWriter implements ClassVisitor {
   // --------------------------------------------------------------------------
 
   public void visit (
+    final int version,
     final int access,
     final String name,
     final String superName,
     final String[] interfaces,
     final String sourceFile)
   {
+    this.version = version;
     this.access = access;
     this.name = newClass(name);
     this.superName = superName == null ? 0 : newClass(superName);
@@ -579,7 +591,6 @@ public class ClassWriter implements ClassVisitor {
       fields.putShort(newUTF8("Deprecated")).putInt(0);
     }
     if (attrs != null) {
-      attrs.getSize(this, null, 0, -1, -1);
       attrs.put(this, null, 0, -1, -1, fields);
     }
   }
@@ -709,6 +720,18 @@ public class ClassWriter implements ClassVisitor {
     if (cst instanceof Integer) {
       int val = ((Integer)cst).intValue();
       return newInteger(val);
+    } else if (cst instanceof Byte) {
+      int val = ((Byte)cst).intValue();
+      return newInteger(val);
+    } else if (cst instanceof Character) {
+      int val = ((Character)cst).charValue();
+      return newInteger(val);
+    } else if (cst instanceof Short) {
+      int val = ((Short)cst).intValue();
+      return newInteger(val);
+    } else if (cst instanceof Boolean) {
+      int val = ((Boolean)cst).booleanValue() ? 1 : 0;
+      return newInteger(val);
     } else if (cst instanceof Float) {
       float val = ((Float)cst).floatValue();
       return newFloat(val);
@@ -747,6 +770,22 @@ public class ClassWriter implements ClassVisitor {
     return newConstItem(cst).index;
   }
 
+  public int newConstInt (final int i) {
+    return newInteger(i).index;
+  }
+
+  public int newConstLong (final long l) {
+    return newLong(l).index;
+  }
+
+  public int newConstFloat (final float f) {
+    return newFloat(f).index;
+  }
+
+  public int newConstDouble (final double d) {
+    return newDouble(d).index;
+  }
+
   /**
    * Adds an UTF8 string to the constant pool of the class being build. Does
    * nothing if the constant pool already contains a similar item. <i>This
